<?xml version="1.0" encoding="UTF-8"?>

<!-- ***********************************************************************************
Copyright &#xa9; 2002 The Board of Trustees of the University of Illinois
All rights reserved.

Distributed under the University of Illinois/NCSA Open Source License (see License.html)

dc.title:				ead-dc.xsl
dc.format:			text/xsl
dc.type:				software
dc.description:	Transform the base metadata in an EAD finding aide into an XML RDF Dublin
								Core metadata file
dc.creator:			Christopher J. Prom, prom@staff.uiuc.edu
dc.creator:			Thomas G. Habing, thabing@uiuc.edu
dc.creator:			Yuping Tseng, ytseng1@uiuc.edu
dc.date:				2002-01, 2002-05
*************************************************************************************** -->


<xsl:stylesheet
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:dc="http://purl.org/dc/elements/1.1/"
	xmlns:dcterms="http://purl.org/dc/terms/"
	xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
	version="1.0">

	<xsl:output	method="xml" encoding="UTF-8" indent="yes"/>

    <xsl:param name="identifier" select="ead/eadheader/eadid/@url"/>
    <xsl:param name="localhost" select="'http://library.wcsu.edu/cao/'"/>

	<xsl:template match="/">

	<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:dc="http://purl.org/dc/elements/1.1/">
		<xsl:element name="rdf:Description">
			<xsl:attribute name="rdf:about">
				<xsl:value-of select="$identifier"/>
			</xsl:attribute>

			<!--identifier-->
			<xsl:element name="dc:identifier">
				<xsl:value-of select="$identifier"/>
			</xsl:element>

	  		<!--title-->
  			<xsl:choose>
  				<xsl:when test="/ead//archdesc/did/unittitle">
  					<xsl:element name="dc:title">
  						<xsl:apply-templates mode="unittitle" select="/ead//archdesc/did/unittitle//text()"/>
                        <xsl:if test="/ead//eadheader/filedesc/titlestmt/subtitle">
                          <xsl:text>: </xsl:text>
                          <xsl:value-of select="normalize-space(/ead//eadheader/filedesc/titlestmt/subtitle)"/>
                        </xsl:if>
	  				</xsl:element>
  				</xsl:when>
  				<xsl:when test="/ead//eadheader/filedesc/titlestmt/titleproper">
  					<xsl:element name="dc:title">
  						<xsl:value-of select="normalize-space(/ead//eadheader/filedesc/titlestmt/titleproper)"/>
                        <xsl:if test="following-sibling::subtitle">
                          <xsl:text>: </xsl:text>
                          <xsl:value-of select="following-sibling::subtitle"/>
                        </xsl:if>
	  				</xsl:element>
  				</xsl:when>
  			</xsl:choose>

	  		<!--date-->
  			<xsl:choose>
  				<xsl:when test="/ead//archdesc/did/unittitle/unitdate">
  					<xsl:element name="dc:date">
  						<xsl:value-of select="normalize-space(/ead//archdesc/did/unittitle/unitdate)"/>
	  				</xsl:element>
  				</xsl:when>
  				<xsl:when test="/ead//archdesc/did/unitdate">
  					<xsl:element name="dc:date">
  						<xsl:value-of select="normalize-space(/ead//archdesc/did/unitdate)"/>
	  				</xsl:element>
  				</xsl:when>
  			</xsl:choose>

  			<!--creator-->
  			<xsl:choose>
  				<xsl:when test="/ead//archdesc/did/origination">
  					<xsl:element name="dc:creator">
  						<xsl:value-of select="normalize-space(/ead//archdesc/did/origination)"/>
	  				</xsl:element>
  				</xsl:when>
			</xsl:choose>

  			<!--type-->
			<xsl:element name="dc:type">
				<xsl:text>text</xsl:text>
			</xsl:element>
			<xsl:element name="dc:type">
				<xsl:text>archives or manuscripts</xsl:text>
			</xsl:element>
	  		<xsl:choose>
  				<xsl:when test="/ead//archdesc/@level">
  					<xsl:element name="dc:type">
  						<xsl:value-of select="normalize-space(/ead//archdesc/@level)"/>
  					</xsl:element>
	  			</xsl:when>
			</xsl:choose>

			<!--abstract-->
  			<xsl:choose>
  				<xsl:when test="/ead//archdesc/did/abstract">
  					<xsl:element name="dcterms:abstract">
  						<xsl:value-of select="normalize-space(/ead//archdesc/did/abstract)"/>
	  				</xsl:element>
  				</xsl:when>
			</xsl:choose>

			<!--description-->
	  		<xsl:choose>
  				<xsl:when test="/ead//archdesc/scopecontent">
  					<xsl:element name="dc:description">
  						<xsl:value-of select="normalize-space(/ead//archdesc/scopecontent)"/>
	  				</xsl:element>
	  			</xsl:when>
			</xsl:choose>

			<!--extent-->
	  		<xsl:choose>
  				<xsl:when test="/ead//archdesc/did/physdesc">
  					<xsl:element name="dcterms:extent">
  						<xsl:value-of select="normalize-space(/ead//archdesc/did/physdesc)"/>
  					</xsl:element>
	  			</xsl:when>
			</xsl:choose>

			<!--subject-->
			<xsl:for-each select="/ead//archdesc/controlaccess//corpname|/ead//archdesc/controlaccess//famname|/ead//archdesc/controlaccess//function|/ead//archdesc/controlaccess//genreform|/ead//archdesc/controlaccess//name|/ead//archdesc/controlaccess//occupation|/ead//archdesc/controlaccess//persname|/ead//archdesc/controlaccess//subject|/ead//archdesc/controlaccess//title">
  				<xsl:element name="dc:subject">
  					<xsl:value-of select="normalize-space(.)"/>
  				</xsl:element>
			</xsl:for-each>

			<!--spatial-->
			<xsl:for-each select="/ead//archdesc/controlaccess//geogname">
  				<xsl:element name="dcterms:spatial">
  					<xsl:value-of select="normalize-space(.)"/>
  				</xsl:element>
			</xsl:for-each>

			<!--publisher-->
  			<xsl:choose>
  				<xsl:when test="/ead//archdesc/did/repository">
  					<xsl:element name="dc:publisher">
  						<xsl:value-of select="normalize-space(/ead//archdesc/did/repository)"/>
	  				</xsl:element>
  				</xsl:when>
  				<xsl:when test="/ead//eadheader/filedesc/publicationstmt/publisher">
  					<xsl:element name="dc:publisher">
  						<xsl:value-of select="normalize-space(/ead//eadheader/filedesc/publicationstmt/publisher)"/>
	  				</xsl:element>
  				</xsl:when>
  			</xsl:choose>

			<!--language-->
	  		<xsl:choose>
  				<xsl:when test="/ead//archdesc/@langmaterial">
  					<xsl:element name="dc:language">
  						<xsl:value-of select="normalize-space(/ead//archdesc/@langmaterial)"/>
  					</xsl:element>
	  			</xsl:when>
			</xsl:choose>

            <!--source xml-->
            <xsl:choose>
              <xsl:when test="/ead/eadheader/eadid">
                <xsl:variable name="repository">
                  <xsl:choose>
                    <xsl:when test="/ead/eadheader/eadid/@mainagencycode = 'US-ct'">statelib</xsl:when>
                    <xsl:when test="/ead/eadheader/eadid/@mainagencycode = 'US-ctnbt'">ccsu</xsl:when>
                    <xsl:when test="/ead/eadheader/eadid/@mainagencycode = 'US-ctwilln'">ecsu</xsl:when>
                    <xsl:when test="/ead/eadheader/eadid/@mainagencycode = 'US-ctnhn'">scsu</xsl:when>
                    <xsl:when test="/ead/eadheader/eadid/@mainagencycode = 'US-ctdabn'">wcsu</xsl:when>
                    <xsl:when test="/ead/eadheader/eadid/@mainagencycode = 'US-UCW'">uconn</xsl:when>
                  </xsl:choose>
                </xsl:variable>
                <xsl:variable name="filename" select="/ead/eadheader/eadid"/>
                <xsl:element name="dc:source"> 
                  <xsl:value-of select="concat($localhost, $repository, '/', $filename, '.xml')"/>
                </xsl:element>
              </xsl:when>
            </xsl:choose>
          </xsl:element>
     	</rdf:RDF>
	</xsl:template>

	<xsl:template match="text()" mode="unittitle">
		<xsl:if test="local-name(..) != 'unitdate'"><xsl:value-of select="normalize-space(.)"/></xsl:if>
	</xsl:template>

</xsl:stylesheet>
