<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:z="http://indexdata.com/zebra-2.0"
                xmlns:dc="http://purl.org/dc/elements/1.1/"
                xmlns:dcterms="http://purl.org/dc/terms/"
                xmlns:xlink="http://www.w3.org/1999/xlink"
                exclude-result-prefixes="xlink  dc"
                version="1.0">

  <!-- xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" -->


  <xsl:output indent="yes" method="xml" version="1.0" encoding="UTF-8"/>

  <!-- disable all default text node output -->
  <xsl:template match="text()"/>
  
  <xsl:template match="/">    
    <z:record z:id="{normalize-space(ead/eadheader/eadid)}">
      <xsl:apply-templates/>
    </z:record>
  </xsl:template>

  <xsl:template match="/ead/eadheader/eadid">
    <z:index name="dc_publisher:p dc_publisher:w">
      <xsl:value-of select="@mainagencycode"/>
    </z:index>
    <z:index name="dc_identifier:0">
      <xsl:value-of select="normalize-space(.)"/>
    </z:index>
  </xsl:template>

  <xsl:template match="/ead/archdesc">
    <z:index name="dc_language:w">
      <xsl:value-of select="@langmaterial"/>
    </z:index>
    <z:index name="dc_type:w dc_type:p">
       <xsl:value-of select="@level" />
    </z:index>
    <!-- after getting these attribute pass to other templates -->
    <xsl:apply-templates/>
  </xsl:template>

    <xsl:template match="/ead/archdesc/did/origination">
    <z:index name="any:w dc_creator:w dc_creator:p">
      <xsl:value-of select="normalize-space(.)"/>
    </z:index>
  </xsl:template>

  <xsl:template match="//unittitle">
    <z:index name="any:w dc_title:w dc_title:p">
      <xsl:value-of select="normalize-space(.)"/>
    </z:index>
  </xsl:template>

  <xsl:template match="//controlaccess//corpname | //controlaccess//famname | //controlaccess//function | //controlaccess//genreform | //controlaccess//name | //controlaccess//occupation | //controlaccess//persname | //controlaccess//subject | //controlaccess//title">
    <z:index name="any:w dc_subject:w dc_subject:p">
      <xsl:value-of select="normalize-space(.)"/>
    </z:index>
  </xsl:template>

  <xsl:template match="//controlaccess/geogname">
    <z:index name="any:w dc_spatial:w dc_spatial:p">
      <xsl:value-of select="normalize-space(.)"/>
    </z:index>
  </xsl:template>

  <xsl:template match="//abstract|//accruals|//altformavail|//apraisal|//bibliography|//bioghist|//custohiist|//altformatavail|//orginalsloc|//fileplan|//odd|//note|//acqinfo|//index|//legalstatus|//physloc|//physfacet|//prefercite|//processinfo|//relatedmaterial|//scopecontent|//separatedmaterial">
    <z:index name="any:w dc_description:w">
      <xsl:value-of select="normalize-space(.)"/>
    </z:index>
  </xsl:template>

  <xsl:template match="//unitdate">
    <xsl:choose>
      <xsl:when test="contains(@normal, '/')">
        <z:index name="dc_date:y">
          <xsl:value-of select="substring-before(@normal, '/')"/>
        </z:index>
        <z:index name="dc_date:y">
          <xsl:value-of select="substring-after(@normal, '/')"/>
        </z:index>
       </xsl:when>
       <xsl:otherwise>
        <z:index name="dc_date:y">
          <xsl:value-of select="@normal"/>
        </z:index>
      </xsl:otherwise>
     </xsl:choose>
  </xsl:template>

  <xsl:template match="//dimensions">
    <z:index name="dc_format:0">
      <xsl:value-of select="."/>
    </z:index>
  </xsl:template>


  <xsl:template match="//accessrestrict | //userrestrict">
    <z:index name="dc_rights:p dc_rights:w">
      <xsl:value-of select="."/>
    </z:index>
  </xsl:template>

</xsl:stylesheet>
